==> groonga-8.0.7-x86.zip: groonga-8.0.7-x86/include/groonga/groonga.h <==
/*
  Copyright(C) 2014-2018 Brazil
  Copyright(C) 2018 Kouhei Sutou <kou@clear-code.com>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#pragma once

#include "groonga/portability.h"
#include "groonga/groonga.h"

#include "groonga/accessor.h"
#include "groonga/array.h"
#include "groonga/arrow.h"
#include "groonga/cache.h"
#include "groonga/column.h"
#include "groonga/config.h"
#include "groonga/dat.h"
#include "groonga/db.h"
#include "groonga/dump.h"
#include "groonga/error.h"
#include "groonga/expr.h"
#include "groonga/file_reader.h"
#include "groonga/geo.h"
#include "groonga/hash.h"
#include "groonga/highlighter.h"
#include "groonga/id.h"
#include "groonga/ii.h"
#include "groonga/obj.h"
#include "groonga/operator.h"
#include "groonga/option.h"
#include "groonga/output.h"
#include "groonga/pat.h"
#include "groonga/raw_string.h"
#include "groonga/request_canceler.h"
#include "groonga/request_timer.h"
#include "groonga/string.h"
#include "groonga/table.h"
#include "groonga/thread.h"
#include "groonga/time.h"
#include "groonga/token.h"
#include "groonga/token_metadata.h"
#include "groonga/type.h"
#include "groonga/util.h"
#include "groonga/window_function.h"
#include "groonga/windows.h"
#include "groonga/windows_event_logger.h"
#include "groonga/vector.h"

==> groonga-10.0.3-x86.zip: groonga-10.0.3-x86/include/groonga/groonga.h <==
/*
  Copyright(C) 2014-2018  Brazil
  Copyright(C) 2018-2020  Sutou Kouhei <kou@clear-code.com>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#pragma once

#include "groonga/version.h"

#include "groonga/portability.h"
#include "groonga/groonga.h"
#include "groonga/posting.h"

#include "groonga/accessor.h"
#include "groonga/array.h"
#include "groonga/arrow.h"
#include "groonga/cache.h"
#include "groonga/column.h"
#include "groonga/config.h"
#include "groonga/dat.h"
#include "groonga/db.h"
#include "groonga/dump.h"
#include "groonga/error.h"
#include "groonga/expr.h"
#include "groonga/file_reader.h"
#include "groonga/geo.h"
#include "groonga/hash.h"
#include "groonga/highlighter.h"
#include "groonga/id.h"
#include "groonga/ii.h"
#include "groonga/index_column.h"
#include "groonga/memory.h"
#include "groonga/obj.h"
#include "groonga/operator.h"
#include "groonga/option.h"
#include "groonga/output.h"
#include "groonga/output_columns.h"
#include "groonga/pat.h"
#include "groonga/proc.h"
#include "groonga/raw_string.h"
#include "groonga/request_canceler.h"
#include "groonga/request_timer.h"
#include "groonga/result_set.h"
#include "groonga/selector.h"
#include "groonga/string.h"
#include "groonga/table.h"
#include "groonga/thread.h"
#include "groonga/time.h"
#include "groonga/token.h"
#include "groonga/token_cursor.h"
#include "groonga/token_metadata.h"
#include "groonga/type.h"
#include "groonga/util.h"
#include "groonga/window_function.h"
#include "groonga/window_function_executor.h"
#include "groonga/windows.h"
#include "groonga/windows_event_logger.h"
#include "groonga/vector.h"
